@@ -2,6 +2,7 @@
 drawing_type_instances.py
 """
 population = [
+    # Diagram types
     {'Name': 'Starr class diagram'},
     {'Name': 'xUML class diagram'},
     {'Name': 'Shlaer-Mellor class diagram'},
@@ -13,4 +14,8 @@ population = [
 
     {'Name': 'Starr domain diagram'},
     {'Name': 'xUML domain diagram'},
+
+    # Frame styles
+    {'Name': 'OS Engineer large frame'},   # For large sheet sizes (D, E, A2-A0)
+    {'Name': 'OS Engineer medium frame'},  # For medium sheet sizes (tabloid, A3)
 ]
\ No newline at end of file
