@@ -3,6 +3,37 @@ text_presentation_instances.py
 """
 
 population = [
+    # Frame OS Engineer, default
+    # Large
+    {'Asset': 'Open title', 'Presentation': 'default', 'Drawing type': 'OS Engineer large frame',
+     'Text style': 'Corner Title Large'},
+    {'Asset': 'Open copyright notice', 'Presentation': 'default', 'Drawing type': 'OS Engineer large frame',
+     'Text style': 'boilerplate'},
+    {'Asset': 'Block title', 'Presentation': 'default', 'Drawing type': 'OS Engineer large frame',
+     'Text style': 'Block Title Large'},
+    {'Asset': 'Block body', 'Presentation': 'default', 'Drawing type': 'OS Engineer large frame',
+     'Text style': 'Block Body Large'},
+
+    # Medium
+    {'Asset': 'Open title', 'Presentation': 'default', 'Drawing type': 'OS Engineer medium frame',
+     'Text style': 'Corner Title Medium'},
+    {'Asset': 'Open copyright notice', 'Presentation': 'default', 'Drawing type': 'OS Engineer medium frame',
+     'Text style': 'boilerplate'},
+    {'Asset': 'Block title', 'Presentation': 'default', 'Drawing type': 'OS Engineer medium frame',
+     'Text style': 'Block Title Medium'},
+    {'Asset': 'Block body', 'Presentation': 'default', 'Drawing type': 'OS Engineer medium frame',
+     'Text style': 'Block Body Medium'},
+    #
+    # # Small
+    # {'Asset': 'Open title large', 'Presentation': 'default', 'Drawing type': 'OS Engineer large',
+    #  'Text style': 'Corner Title Large'},
+    # {'Asset': 'Open copyright notice large', 'Presentation': 'default', 'Drawing type': 'OS Engineer large',
+    #  'Text style': 'boilerplate'},
+    # {'Asset': 'Block title large', 'Presentation': 'default', 'Drawing type': 'OS Engineer large',
+    #  'Text style': 'Block title Large'},
+    # {'Asset': 'Block body large', 'Presentation': 'default', 'Drawing type': 'OS Engineer large',
+    #  'Text style': 'Block Body Large'},
+
     # Starr class diagram, default
     {'Asset': 'label', 'Presentation': 'default', 'Drawing type': 'Starr class diagram', 'Text style': 'p9body'},
     {'Asset': 'binary association name', 'Presentation': 'default', 'Drawing type': 'Starr class diagram', 'Text style': 'p9body'},
