@@ -4,17 +4,19 @@ canvas.py
 This is the Flatland (and not the cairo) Canvas class
 """
 import sys
-from flatland.flatland_exceptions import InvalidOrientation
-from flatland.node_subsystem.diagram_layout_specification import DiagramLayoutSpecification as diagram_layout
-from flatland.connector_subsystem.connector_layout_specification import ConnectorLayoutSpecification as connector_layout
-from flatland.datatypes.geometry_types import Rect_Size, Position
+import logging
+from flatland.flatland_exceptions import InvalidOrientation, NonSystemInitialLayer
+from flatland.node_subsystem.diagram_layout_specification import DiagramLayoutSpecification
+from flatland.connector_subsystem.connector_layout_specification import ConnectorLayoutSpecification
+from flatland.datatypes.geometry_types import Rect_Size, Padding
 from flatland.node_subsystem.diagram import Diagram
 from flatland.drawing_domain.tablet import Tablet
-from flatland.node_subsystem.sheet import Sheet, Group
+from flatland.sheet_subsystem.sheet import Sheet, Group
 from flatland.decoration_subsystem.symbol import Symbol
 
 # All sheet and canvas related constants are kept together here for easy review and editing
 points_in_cm = 28.3465
+points_in_mm = 2.83465
 points_in_inch = 72
 
 
@@ -38,7 +40,7 @@ class Canvas:
     """
 
     def __init__(self, diagram_type: str, presentation: str, notation: str, standard_sheet_name: str, orientation: str,
-                 drawoutput=sys.stdout.buffer, show_margin=False):
+                 diagram_padding: Padding, drawoutput=sys.stdout.buffer):
         """
         Constructor
 
@@ -48,11 +50,11 @@ class Canvas:
         :param standard_sheet_name: A US or international printer sheet size such as A1, tabloid, letter
         :param orientation: portrait or landscape
         :param drawoutput: A standard IO binary object obtained from sys
-        :param show_margin: For diagnostics, show the canvas margin in the drawn output
         """
+        self.logger = logging.getLogger(__name__)
         # Load layout specifications
-        diagram_layout()
-        connector_layout()
+        DiagramLayoutSpecification()
+        ConnectorLayoutSpecification()
 
         self.Sheet = Sheet(standard_sheet_name)  # Ensure that the user has specified a known sheet size
         if orientation not in ('portrait', 'landscape'):
@@ -68,33 +70,33 @@ class Canvas:
             height=int(round(h * factor)),
             width=int(round(w * factor))
         )
-        self.Margin = diagram_layout.Default_margin
-        self.Diagram = Diagram(self, diagram_type_name=diagram_type, presentation=presentation, notation_name=notation)
-        # Load symbol data
-        Symbol(diagram_type=self.Diagram.Diagram_type.Name, notation=self.Diagram.Notation)
+        self.Margin = DiagramLayoutSpecification.Default_margin
 
-        self.Tablet = Tablet(
-            size=self.Size, output_file=drawoutput,
-            # Drawing types include notation such as 'xUML class diagram' since notation affects the choice
-            # of shape and text styles.  An xUML class diagram association class stem is dashed, for example.
-            drawing_type=' '.join([self.Diagram.Notation, diagram_type, 'diagram']), presentation=presentation
+        # Create the one and only Tablet instance and initialize it with the Presentation on the diagram
+        # Layer
+        try:
+            self.Tablet = Tablet(
+                size=self.Size, output_file=drawoutput,
+                # Drawing types include notation such as 'xUML class diagram' since notation affects the choice
+                # of shape and text styles.  An xUML class diagram association class stem is dashed, for example.
+                drawing_type=' '.join([notation, diagram_type, 'diagram']), presentation=presentation,
+                layer='diagram'
+            )
+        except NonSystemInitialLayer:
+            self.logger.exception("Initial layer [diagram] not found in Tablet layer order")
+            sys.exit()
+        self.Diagram = Diagram(
+            self, diagram_type_name=diagram_type, layer=self.Tablet.layers['diagram'],
+            notation_name=notation, padding=diagram_padding,
         )
-        self.Show_margin = show_margin
+        # Load symbol data
+        self.logger.info("Loading symbol decoration data from flatland database")
+        Symbol(diagram_type=self.Diagram.Diagram_type.Name, notation=self.Diagram.Notation)
 
     def render(self):
         """
         Draw all content of this Canvas onto the Tablet
         """
-        if self.Show_margin:
-            # Add the margin boundary rectangle to the Tablet
-            # The margin rectangle represents the drawable area defined for our Canvas
-            # and may be equal to or smaller than the Tablet area
-            drawable_origin = Position(x=self.Margin.left, y=self.Margin.bottom)
-            draw_area_height = self.Size.height - self.Margin.top - self.Margin.bottom
-            draw_area_width = self.Size.width - self.Margin.left - self.Margin.right
-            draw_area_size = Rect_Size(height=draw_area_height, width=draw_area_width)
-            self.Tablet.add_rectangle(asset='margin', lower_left=drawable_origin, size=draw_area_size)
-
         # Now add all Diagram content to the Tablet
         self.Diagram.render()
 
@@ -102,9 +104,9 @@ class Canvas:
         self.Tablet.render()
 
     def __repr__(self):
-        return f'Canvas(diagram_type={self.Diagram.Diagram_type}, presentation={self.Diagram.Presentation},' \
+        return f'Canvas(diagram_type={self.Diagram.Diagram_type}, layer={self.Diagram.Layer},' \
                f'notation={self.Diagram.Notation}, standard_sheet_name={self.Sheet}, orientation={self.Orientation},' \
-               f'drawoutput={self.Tablet.Output_file}, show_margin={self.Show_margin})'
+               f'drawoutput={self.Tablet.Output_file} )'
 
     def __str__(self):
         return f'Sheet: {self.Sheet}, Orientation: {self.Orientation}, '\
